@@ -22,18 +22,21 @@ class MySocketServer:
         self.laststarttime = datetime.now()
         self.lastseconds=0
         self.lastresetseconds=-1
+        self.updateinterval = 2
+        self.nextfeedtime = laststarttime + timedelta(minutes = updateinterval)
 
     def setNewCarsFeeder(self,feeder):
         self.feeder = feeder
 
-    async def handle_client(self,reader, writer, cars, timeout,nextfeedtime):        
+    async def handle_client(self,reader, writer, cars, timeout,nextfeedtime,updateinterval):        
 
         try:
 
+            self.updateinterval = updateinterval
+            self.nextfeedtime = self.laststarttime + timedelta(minutes = self.updateinterval) 
             timenow = datetime.now()
-            nextfeedtime2 = self.laststarttime + timedelta(minutes = 5) 
-
-            if timenow == nextfeedtime2 and self.feeder is not None:
+            
+            if timenow == self.nextfeedtime and self.feeder is not None:
                 self.lastresetseconds = self.lastseconds #161
                 self.laststarttime = timenow
                 newcars,timeout,nextfeedtime = self.feeder.getCars(5)
